From f7ec00b2f8ba3efc5bdeacef9c813f8a826ae3be Mon Sep 17 00:00:00 2001
From: Patrick Anders <p.anders@timmehosting.de>
Date: Wed, 10 Dec 2014 08:44:26 -0500
Subject: [PATCH] add Spdy option - http://en.wikipedia.org/wiki/SPDY
---
interface/web/admin/users_edit.php | 119 ++++++++++++++++++++++++++++++++++++++++++++++++++++++-----
1 files changed, 108 insertions(+), 11 deletions(-)
diff --git a/interface/web/admin/users_edit.php b/interface/web/admin/users_edit.php
index 8dab858..0a14ca5 100644
--- a/interface/web/admin/users_edit.php
+++ b/interface/web/admin/users_edit.php
@@ -1,6 +1,6 @@
<?php
/*
-Copyright (c) 2007, Till Brehm, projektfarm Gmbh
+Copyright (c) 2008, Till Brehm, projektfarm Gmbh
All rights reserved.
Redistribution and use in source and binary forms, with or without modification,
@@ -38,19 +38,116 @@
* End Form configuration
******************************************/
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],$_SESSION["s"]["module"]["name"])) {
- header("Location: ../index.php");
- exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('admin');
// Loading classes
$app->uses('tpl,tform,tform_actions');
+$app->load('tform_actions');
-// let tform_actions handle the page
-$app->tform_actions->onLoad();
+class page_action extends tform_actions {
-?>
\ No newline at end of file
+ function onBeforeInsert() {
+ global $app, $conf;
+
+ //* Security settings check
+ if(isset($this->dataRecord['typ']) && $this->dataRecord['typ'][0] == 'admin') {
+ $app->auth->check_security_permissions('admin_allow_new_admin');
+ }
+
+ if(!in_array($this->dataRecord['startmodule'], $this->dataRecord['modules'])) {
+ $app->tform->errorMessage .= $app->tform->wordbook['startmodule_err'];
+ }
+
+
+
+ }
+
+ function onBeforeUpdate() {
+ global $app, $conf;
+
+ if($conf['demo_mode'] == true && $_REQUEST['id'] <= 3) $app->error('This function is disabled in demo mode.');
+
+ //* Security settings check
+ if(isset($this->dataRecord['typ']) && $this->dataRecord['typ'][0] == 'admin') {
+ $app->auth->check_security_permissions('admin_allow_new_admin');
+ }
+
+ if(@is_array($this->dataRecord['modules']) && !in_array($this->dataRecord['startmodule'], $this->dataRecord['modules'])) {
+ $app->tform->errorMessage .= $app->tform->wordbook['startmodule_err'];
+ }
+
+ $this->oldDataRecord = $app->tform->getDataRecord($this->id);
+
+ //* A user that belongs to a client record (client or reseller) may not have typ admin
+ if(isset($this->dataRecord['typ']) && $this->dataRecord['typ'][0] == 'admin' && $this->oldDataRecord['client_id'] > 0) {
+ $app->tform->errorMessage .= $app->tform->wordbook['client_not_admin_err'];
+ }
+
+ }
+
+ /*
+ This function is called automatically right after
+ the data was successful updated in the database.
+ */
+ function onAfterUpdate() {
+ global $app, $conf;
+
+ $client = $app->db->queryOneRecord("SELECT * FROM sys_user WHERE userid = ".$this->id);
+ $client_id = $app->functions->intval($client['client_id']);
+ $username = $app->db->quote($this->dataRecord["username"]);
+ $old_username = $app->db->quote($this->oldDataRecord['username']);
+
+ // username changed
+ if(isset($conf['demo_mode']) && $conf['demo_mode'] != true && isset($this->dataRecord['username']) && $this->dataRecord['username'] != '' && $this->oldDataRecord['username'] != $this->dataRecord['username']) {
+ $sql = "UPDATE client SET username = '$username' WHERE client_id = $client_id AND username = '$old_username'";
+ $app->db->query($sql);
+ $tmp = $app->db->queryOneRecord("SELECT * FROM sys_group WHERE client_id = $client_id");
+ $app->db->datalogUpdate("sys_group", "name = '$username'", 'groupid', $tmp['groupid']);
+ unset($tmp);
+ }
+
+ // password changed
+ if(isset($conf['demo_mode']) && $conf['demo_mode'] != true && isset($this->dataRecord["passwort"]) && $this->dataRecord["passwort"] != '') {
+ $password = $app->db->quote($this->dataRecord["passwort"]);
+ $salt="$1$";
+ $base64_alphabet='ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
+ for ($n=0;$n<8;$n++) {
+ $salt.=$base64_alphabet[mt_rand(0, 63)];
+ }
+ $salt.="$";
+ $password = crypt(stripslashes($password), $salt);
+ $sql = "UPDATE client SET password = '$password' WHERE client_id = $client_id AND username = '$username'";
+ $app->db->query($sql);
+ }
+
+ // language changed
+ if(isset($conf['demo_mode']) && $conf['demo_mode'] != true && isset($this->dataRecord['language']) && $this->dataRecord['language'] != '' && $this->oldDataRecord['language'] != $this->dataRecord['language']) {
+ $language = $app->db->quote($this->dataRecord["language"]);
+ $sql = "UPDATE client SET language = '$language' WHERE client_id = $client_id AND username = '$username'";
+ $app->db->query($sql);
+ }
+
+ // reseller status changed
+ /*
+ if(isset($this->dataRecord["limit_client"]) && $this->dataRecord["limit_client"] != $this->oldDataRecord["limit_client"]) {
+ $modules = $conf['interface_modules_enabled'];
+ if($this->dataRecord["limit_client"] > 0) $modules .= ',client';
+ $modules = $app->db->quote($modules);
+ $client_id = $this->id;
+ $sql = "UPDATE sys_user SET modules = '$modules' WHERE client_id = $client_id";
+ $app->db->query($sql);
+ }
+ */
+ parent::onAfterUpdate();
+ }
+
+}
+
+$page = new page_action;
+$page->onLoad();
+
+?>
--
Gitblit v1.9.1